==> atedit-1.03.zip: atedit-1.03/setup/it/messages_it.tcl <==
#
# A.T.Edit -- Another Tcl/Tk based text editor
# Copyright (C) 2004 Shinji Moiino
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
#-- messages_it --
#
#--- Setup program messages ---------------------------------------------------
#
set M001 "A.T.Edit versione 1.03 Installazione"
set M002 "Percorso comando wish"
set M003 "Seleziona"
set M004 "Comando wish"
set M005 "Cartella di intallazione"
set M006 "Cartella di intallazione"
set M007 "Cartella file di configurazione"
set M008 "Cartella file di configurazione"
set M009 "Installazione"
set M010 "Cancella"
set M011 "Errore"
set M012 "Comando"
set M013 "Impossibile eseguire"
set M014 "Percorso inesistente. Create la cartella ?"
set M015 "Impossibile creare il file di configurazione."
set M016 "Si  verificato un errore durante l'Intallazione"
set M017 "Terminare l'installazione"
set M018 "Terminare l'installazione ?"
set M019 "Impossibile copiare i files"
set M020 "Completato"
set M021 "Completato"
set M022 "Copia dei file in corso.."
set M023 "Termina"
set M024 ": Inpossibile creare"
set M025 "Impossibile eliminare i vecchi files"
set M026 "Impossibile creare i file di avvio"
set M027 "Lingua"
set WM027 10

==> atedit-1.04.zip: atedit-1.04/setup/it/messages_it.tcl <==
#
# A.T.Edit -- Another Tcl/Tk based text editor
# Copyright (C) 2004 Shinji Moiino
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
#-- messages_it --
#
#--- Setup program messages ---------------------------------------------------
#
set M001 "A.T.Edit versione 1.04 Installazione"
set M002 "Percorso comando wish"
set M003 "Seleziona"
set M004 "Comando wish"
set M005 "Cartella di intallazione"
set M006 "Cartella di intallazione"
set M007 "Cartella file di configurazione"
set M008 "Cartella file di configurazione"
set M009 "Installazione"
set M010 "Cancella"
set M011 "Errore"
set M012 "Comando"
set M013 "Impossibile eseguire"
set M014 "Percorso inesistente. Create la cartella ?"
set M015 "Impossibile creare il file di configurazione."
set M016 "Si \ufffdverificato un errore durante l'Intallazione"
set M017 "Terminare l'installazione"
set M018 "Terminare l'installazione ?"
set M019 "Impossibile copiare i files"
set M020 "Completato"
set M021 "Completato"
set M022 "Copia dei file in corso.."
set M023 "Termina"
set M024 ": Inpossibile creare"
set M025 "Impossibile eliminare i vecchi files"
set M026 "Impossibile creare i file di avvio"
set M027 "Lingua"
set WM027 10
